function adjusted = adjust_position(fixed, to_adjust)
% ADJUST_POSITION Registration of channels.
%   ADJUST_POSITION(FIXED, TO_ADJUST) returns the result of shifting the
%   the pixels of the spatial imageScan channel TO_ADJUST, so that it
%   correlates well with the pixels of the spatial imageScan channel FIXED.
%   Pixels that were shifted  over the boundary of the image, wrap around at the
%   opposite boundary of the image. The pixel matrices of FIXED and TO_ADJUST
%   should have the same size and are assumed to have the same resolution.
%   Author of original PV-WAVE-file: Pieter van Schendel, 10.06.97.

% Check input
try
    parser = inputParser;
    parser.addRequired('fixed', @(in)is_channel(in) && ...
        strcmp(fixed.type,'imageScan') && ...
        strcmp(fixed.pixel_domain,'spatial'));
    parser.addRequired('to_adjust', @(in)is_channel(in) && ...
        strcmp(to_adjust.type,'imageScan') && ...
        strcmp(to_adjust.pixel_domain,'spatial'));
    parser.parse(fixed, to_adjust);
catch error
    me = MException('spm:adjust_position:input_error', 'Invalid input: %s', ...
        error.message);
    throw(me);
end

if sum(size(fixed.pixels) ~= size(to_adjust.pixels)) ~= 0
    me = MException('spm:adjust_position:inconsistent_sizes', ...
        'Channel pixel matrices have different dimensions.');
    throw(me);
end

% Copy fixed input to output and combine input contexts to output context
adjusted = fixed;
adjusted.context = [fixed.context, to_adjust.context];
% Perform a fast correlation
cor = fft2(fixed.pixels);
cor = abs(ifft2(conj(cor) .* fft2(to_adjust.pixels)));
cor=cor/length(fixed.pixels(:));%following PV-WAVE normalization

% Find the maximum in the cross correlation function
[~, imax] = max(cor(:));
[ypeak, xpeak] = ind2sub(size(cor),imax(1));
shift = [-(ypeak-1), -(xpeak-1)];
adjusted.pixels = circshift(to_adjust.pixels,shift);
end