function out = apply_mask(in, mask)
%APPLY_MASK Binary mask application.
%   APPLY_MASK(IN, MASK) returns the result of applying the binary
%   imageScan channel MASK to the imageScan channel IN. If the mask is 1
%   then the pixel valuein IN is left untouched; if it is 0 the pixel value
%   is set to zero.

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @(in)is_channel(in) && ...
        strcmp(in.type,'imageScan'));
    parser.addRequired('mask', @(mask)is_channel(mask) && ...
        strcmp(mask.type,'imageScan') && ...
        length(find(mask.pixels == 1)) + ...
        length(find(mask.pixels == 0)) ==  numel(mask.pixels));
    parser.parse(in, mask);
catch error
    me = MException('spm:apply_mask:input_error', 'Invalid input: %s', ...
        error.message);
    throw(me);
end

if size(in.pixels,1) ~= size(mask.pixels,1) || ...
        size(in.pixels,2) ~= size(mask.pixels,2)
    me = MException('spm:apply_mask:inconsistent_dimensions', ...
        'Mask and input channel have different dimensions');
    throw(me);
end

% Apply mask
out = in;
out.pixels = in.pixels .* mask.pixels;

end

