function out = change_dpi(in, pixel_h, varargin)
% CHANGE_DPI Channel resampling.
%   CHANGE_DPI(IN, PIXEL_H, PIXEL_V) returns a copy of the spatial channel  
%   IN resampled into PIXEL_H x PIXEL_V pixels. CHANGE_DPI(IN, PIXEL_H), 
%   where IN is of type imageScan behaves like CHANGE_DPI(IN, PIXEL_H, 
%   PIXEL_H). If IN is of type generalScanStandard, it behaves like 
%   CHANGE_DPI(IN, PIXEL_H, IN.axis(2).count).


% Check input
try
    parser = inputParser;
    parser.addRequired('in', @(in)(is_channel(in)  && ...
        strcmp(in.pixel_domain,'spatial')));
    parser.addRequired('pixel_h', @(pixel_h)(isnumeric(pixel_h) && ...
        numel(pixel_h) == 1 && floor(pixel_h) == pixel_h));
    parser.addOptional('pixel_v', NaN,  @(pixel_v)(isnumeric(pixel_v) && ...
        numel(pixel_v) == 1 && floor(pixel_v) == pixel_v));
    parser.parse(in, pixel_h, varargin{:});
    if isnan(parser.Results.pixel_v) 
        switch in.type 
            case 'imageScan'
                pixel_v = pixel_h;
            case 'generalScanStandard'
                pixel_v = size(in.pixels,1);
        end
    else
        pixel_v = parser.Results.pixel_v;
    end
catch error
    me = MException('spm:change_dpi:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Copy in to out
out = in;

% Set new pixel dimensions
out.axis(1).count = pixel_h;
if length(out.axis) > 1
    out.axis(2).count = pixel_v;
end

% Resize pixel matrix
out. pixels = imresize(out.pixels, [pixel_v pixel_h], 'bilinear');

% TO DO: also change intervals?
% TO DO: version not sing image processing toolbox?

end

