function empty = empty_image(x_size, y_size, nx, ny, unit)
%EMPTY_IMAGE Creation of an empty imageScan channel.
%   EMPTY_IMAGE(X_SIZE, Y_SIZE, NX, NY, UNIT) creates an imageScan channel
%   containing an all-zero NX x NY-image with left-lower corner (0,0)
%   and dimensions X_SIZE by Y_SIZE measured in the unit UNIT.
%
%   The display unit of both the channel axes is UNIT. The internal units 
%   are set to 'm' where possible. If no automatic conversion between UNIT 
%   and 'm' can be done, the internal unit is also UNIT. In this case, a 
%   warning is issued.

% Check input
try
    parser = inputParser;
    parser.addRequired('x_size', @(x_size)(numel(x_size) == 1 && ...
        isnumeric(x_size)));
    parser.addRequired('y_size', @(y_size)(numel(y_size) == 1 && ...
        isnumeric(y_size)));
    parser.addRequired('nx', @(nx)(numel(nx) == 1 && isnumeric(nx) && ...
        floor(nx) == nx));
    parser.addRequired('ny', @(ny)(numel(ny) == 1 && isnumeric(ny) && ...
        floor(ny) == ny));
    parser.addRequired('unit', @ischar);
    parser.parse(x_size, y_size, nx, ny, unit);
catch error
    me = MException('spm:empty_image:input_error', 'Invalid input: %s', ...
        error.message);
    throw(me);
end

% Construct channel
empty = image2channel(zeros(ny, nx), x_size, y_size, unit, 'spatial');

end

