function handle = coloured_line_3d(x, y, z, c)
% COLOURED_LINE_3D Multi-colored 3D line plot.
%   COLOURED_LINE_3D(X, Y, Z, C) displays the 3D line plot defined by the 
%   x-, y-, and z-coordinates X, Y and Z, using the color vector C to color
%   the plotted line. The return value is a handle to the plot. The 
%   function has been taken from: 
%   http://tinyurl.com/colored-lines-in-gnu-octavemat
%   To apply coloured_line_3d in a 2D-setting where the colors should be 
%   given by the  value of the plotted function, one can call
%
%   [x,y] = compute_my_data() % get your 3D data from some function
%   z = zeros(length(x),1); % set the z-values to be all zero
%   figure = coloured_line_3d(x,y,z,y); % plot the coloured line

handle = surface(...
    [x(:), x(:)], ...
    [y(:), y(:)], ...
    [z(:), z(:)], ...
    ... % The colour vector
    [c(:), c(:)], ...  
    ... % Colour the edges with flat shading according to the colour vector
    'EdgeColor', 'flat',  ... 
    ... % Don't colour the face (which is zero area)
'FaceColor', 'none'  ...  
    );

end