function to = fft_magnitude(from)
%FFT_MAGNITUDE Fourier transform magnitude.
%   FFT_MAGNITUDE(FROM) returns the magnitude of the Fourier transform of
%   the spatial imageScan channel FROM

% Check input
try
    parser = inputParser;
    parser.addRequired('from', @(from)is_channel(from) && ...
        strcmp(from.type,'imageScan') && ...
        strcmp(from.pixel_domain,'spatial'));
    parser.parse(from);
catch error
    me = MException('spm:fft_magnitude:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Compute Fourier transform magnitude, applying the same scaling as in
% fft_birect
work_image = abs(fft2(from.pixels));
if numel(work_image) ~= 0
    work_image = work_image / numel(work_image);
end

% Construct output channel
to = from;
to.pixels = work_image;
to.pixel_domain = 'frequency';
to.name = sprintf('FFT magnitude of %s', from.name);

end

