function out = flat_tf(in)
%FLAT_TF Construct a flat channel with value one.
%   FLAT_TF(IN) returns a flat channel of value one with the same dimension
%   as the input channel IN. Most of the channel fields are copied from IN.
%   Only the channel (display) unit is set to '1' and the channel display 
%   scale is set to 1. In addition, the pixel domain is set to 'frequency',
%   as the output is thought to be a filter applied in the frequency 
%   domain.

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @is_channel);
    parser.parse(in);
    catch error
    me = MException('spm:flat_tf:input_error', 'Invalid input: %s', ...
        error.message);
    throw(me);
end

% Copy in to out
out = in;

% Set pixels
out.pixels = ones(size(out.pixels));

% Set channel units
out.unit = '1';
out.display_unit = '1';
out.display_scale = 1;

% Set pixel domain
out.pixel_domain = 'frequency';

end

