function dist = dist_v2(nx, dx, ny, dy) %#codegen
% DIST_V2 Function to compute real-life image distances
%   DIST_V2(nx, dx, ny, dy) returns the real-life distance between a pixel 
%   and the closest corner of an image with (nx + 1) x (ny + 1) pixels, 
%   where the real-life distance size in meters of one pixel in x, 
%   y-direction is given by dx, dy resp. The distance is calculated for
%   all pixels (y, x) with 0 <= y < ny and 0 <= x < nx.
%
%   REMARK: The corresponding PV-WAVE function says that the purpose of the
%   function is to create an array of values with the distance from the
%   lower left corner of an image. The implementation, however, seems to do
%   the above.

x2 = 0 : nx - 1;
x2 = (min(x2, nx - x2) * dx).^2;
y2 = 0 : ny - 1;
y2 = (min(y2, ny - y2) * dy).^2;
dist = sqrt(ones(ny, 1) * x2 + y2' * ones(1, nx));

end
