function varargout = find_structures(struct_array, field, value)
%FIND_STRUCTURES Find specific structures in an array of structures
%   FIND_STRUCTURES(STRUCT_ARRAY, FIELD, VALUE) returns the indices
%   in an array of structures where string FIELD has value VALUE. It can 
%   also return the structures themselves. The syntax is analogous to the
%   syntax used for the matlab built-in 'find'.

if verLessThan('matlab', '7.14')
    error(nargoutchk(0, 3, nargout));
else
  nargoutchk(0, 3);
end
field_occurs = arrayfun(@(x)strcmp(x.(field), value), ...
  struct_array, 'uniformoutput', false);
[index1, index2] = find(cell2mat(field_occurs));
linear_index = (index2 - ones(size(index2))) * size(struct_array, 1) + ...
  index1;
structures = struct_array(linear_index);

if nargout == 1
varargout{1} = linear_index;
else 
varargout{1} = index1;
varargout{2} = index2;
end

if nargout == 3
  varargout{3} = structures;
end
      
end
