function [hor_name, vert_name, channel_name] = get_axes_names(channel, ...
    plot_type)
%GET_AXES_NAMES Helper function for spm_display to get varaible names.
%    [IV1_NAME, IV2_NAME, DV_NAME] = GET_AXES_NAMES(CHANNEL) returns
%    the names of the independent and dependent variable(s) of  the channel
%    CHANNEL given the plot type PLOT_TYPE. In case of a  1-dimensional
%    channel the unit of the second independent variable is set to the
%    empty string.

[hor_axis, vert_axis, ~, ~] = get_axes_and_params(channel);

if strcmp(channel.pixel_domain, 'spatial') %Spatial domain
    hor_name = hor_axis.name;
    if ~isempty(vert_axis)
        vert_name = vert_axis.name;
    else
        vert_name = '';
    end
else %Frequency domain
    hor_name = sprintf('%s-Frequency', hor_axis.name);
    if ~isempty(vert_axis)
        vert_name = sprintf('%s-Frequency', vert_axis.name);
    else
        vert_name = '';
    end
end

if strcmp(channel.pixel_domain, 'spatial')
    root_channel_name = channel.name;
else
    root_channel_name = sprintf('FFT(%s)',channel.name);
end

switch plot_type
    case 'real'
        if strcmp(channel.pixel_type, 'real') % Real pixel values
            channel_name = root_channel_name;
        else % Complex pixel values
            channel_name = sprintf('Re[%s]',root_channel_name);
        end
    case 'imaginary'
        channel_name = sprintf('Im[%s]',root_channel_name);
    case 'magnitude'
        channel_name = sprintf('|%s|',root_channel_name);
    case 'log_magnitude'
        channel_name = sprintf('20log_{10}[|%s|]',root_channel_name);
    case 'phase'
        channel_name = sprintf('\\phi[%s]',root_channel_name);
    otherwise
        me = MException(...
            'spm:get_axes_names:unknown_plot_type', ...
            'Unknown plot type.');
        throw(me);
end

end

