function hist_name = get_histogram_name(channel)
%GET_HISTOGRAM_NAME Helper function for spm_hist function to get histogram
%name.
%   GET_HISTOGRAM_NAME(CHANNEL) returns a suitable name for the histogram of
%   channel CHANNEL.

% Search for axes and parameters
[hor_axis, vert_axis, hor_param, vert_param] = ...
    get_axes_and_params(channel);

if strcmp(channel.type, 'generalScanStandard')
    % Get horizontal axis variable names, and lower and upper values
    names = {hor_axis.variable.name}';
    extents = cell2mat({hor_axis.variable.extent});
    starts = zeros(size(names))';
    for i = 1:length(names)
        [~,~, parameter] = find_structures(channel.parameter, ...
            'name', names{i});
        starts(i) = parameter.start_value.fine;
    end
    mins = channel.display_scale * min([starts; starts + extents]);
    maxs = channel.display_scale * max([starts; starts + extents]);
    names_string = mat2vectstr(char(names));
    mins_string = mat2vectstr(mins);
    maxs_string = mat2vectstr(maxs);
    hist_name = sprintf(['Number of pixels on line between ', ...
        '(display unit) points \n', ...
        '%s = %s and %s = %s'], ...
        names_string, mins_string, names_string, maxs_string);
else % Image scan
    % Compute left-lower and right-upper corners of image area
    if hor_axis.variable.extent > 0
        hor_min = hor_param.start_value.fine;
        hor_max = hor_param.start_value.fine + hor_axis.variable.extent;
    else
        hor_max = hor_param.start_value.fine;
        hor_min = hor_param.start_value.fine + hor_axis.variable.extent;
    end
    if vert_axis.variable.extent > 0
        vert_min = vert_param.start_value.fine;
        vert_max = vert_param.start_value.fine + vert_axis.variable.extent;
    else
        vert_max = vert_param.start_value.fine;
        vert_min = vert_param.start_value.fine + vert_axis.variable.extent;
    end
    
    
    hist_name = sprintf(['Number of pixels in rectangle ', ...
        'delimited by (display unit) points \n', ...
         '(%s, %s)_{fine} = (%g, %g) and \n', ...
        '(%s, %s)_{fine} = (%g, %g) %s'], ...
        hor_param.name, vert_param.name, ...
        hor_min, vert_min, ...
        hor_param.name, vert_param.name, ...
        hor_max, vert_max);
end

end

