function sxm = read_sxm(fname) %#codegen
% READ_SXM Read an SXM-file
%      READ_SXM(FNAME) returns the data and header info from the SXM-file
%      FNAME in a structure
fname = get_full_path(fname);
sxm.header = default_sxm_header();
info = default_sxm_info();
%Adding info fields for convenience (removing those later on)
infofields= char(fieldnames(info));
for i = 1:size(infofields, 1)
    name = strtrim(infofields(i, :));
    sxm.header.(name) = info.(name);
end

endTag	= 'SXM_END';
beginTag = 'SXM_VERSION';
if length(fname) < 4  || ~strcmp(fname(end-3:end), '.sxm')
    disp 'File extension is not ''.sxm''. Returning empty image.'
    sxm.data = [];
    return;
end

fid = fopen(fname, 'r');
if fid == -1
    disp 'Cannot open file. Returning empty image.'
    sxm.data = [];
    fclose(fid);
    return;
end

% nLines = 0;
% while (fgets(fid) ~= -1),
%     nLines = nLines+1;
% end
% fclose(fid);
%   Somewhat more complicated than the above to satisfy Matlab coder:
notDone = true;
nLines = 0;
maxLength = 0;
while (notDone),
    nLines = nLines+1;
    line = fgets(fid);
    if nLines == 1
        frewind(fid);
        stripped_line = fgetl(fid);
        if ~strcmp(stripped_line(2:end-1), beginTag)
            disp(['This is not an SXM-file (see start tag). ', ...
                'Returning empty image.']);
            sxm.data = [];
            fclose(fid);
            return;
        end
    end
    maxLength = max(maxLength, length(line));
    notDone = (line ~= -1);
end
fclose(fid);

fid = fopen(fname);
notDone = true;
count = 0;
tagVal = char(zeros(nLines, maxLength));
tag = '';
maxTagValLength = 0;
start = 1;
while notDone
    line = fgetl(fid);
    if isfield(sxm.header, line(2:end-1))
        if(~strcmp(tag, ''))
            if(isfloat(sxm.header.(tag)))
                sxm.header.(tag) = extract_tag_value(...
                    tagVal(start:start+count-1, 1:maxTagValLength), ...
                    'number');
            else
                sxm.header.(tag) = extract_tag_value(...
                    tagVal(start:start+count-1, 1:maxTagValLength), ...
                    'string');
            end
            start = start+count;
        end
        tag = line(2:end-1);
        count = 0;
    else
        count = count + 1;
        if ~isempty(line)
            tagVal(start+count-1, 1:length(line)) = line;
            % Keeping track of maximal length of tag value to satisfy 
            % Matlab R2009b (does not seem to be able to deal with very 
            % long lines)
            maxTagValLength = max(maxTagValLength, length(line));
        end
    end
    notDone = ischar(line) && ~strcmp(line(2:end-1), endTag);
end
fclose(fid);

% Reading byteData
sxm.data = [];
fid = fopen(fname, 'r', 'b');
byteData = fread(fid);

ctrlz = find(byteData == 26); %ctrl-Z
i = 1;
off1 = 0;
if(~isempty(ctrlz))
    while byteData(ctrlz(i) + 1) ~= 4
        i = i + 1; %ctrl-D
    end
    if i <= length(ctrlz)
        off1 = ctrlz(i) + 1;
    end
end

if off1 > 0
    fseek(fid, off1, -1);
    if  sxm.header.SXM_TYPE >= 1 && sxm.header.SXM_TYPE <=4
        switch sxm.header.SXM_TYPE %
            % Supporting long type (sxm.header.SXM_TYPE = 3) although
            % the corresponding PV-WAVE code seems to segfault under
            % 64-bits Windows 7. Trying to mimick behavior seen in XP. The
            % read data is converted to doubles.
            case 1%byte data
                sxm.data =  fread(fid, sxm.header.SXM_PIXELS(1) *...
                    sxm.header.SXM_PIXELS(2));
            case 2%int data
                sxm.data =  fread(fid, sxm.header.SXM_PIXELS(1) *...
                    sxm.header.SXM_PIXELS(2), 'int16');
            case 3%int data
                sxm.data =  fread(fid, sxm.header.SXM_PIXELS(1) *...
                    sxm.header.SXM_PIXELS(2), 'int32');
            case 4%float data
                sxm.data =  fread(fid, sxm.header.SXM_PIXELS(1) *...
                    sxm.header.SXM_PIXELS(2), 'float32');
        end
        sxm.data = reshape(sxm.data, sxm.header.SXM_PIXELS(1), ...
            sxm.header.SXM_PIXELS(2));
        sxm.data = sxm.data';
    else
        disp 'Unknown file type! Returning empty image.'
    end
else
    disp 'Cannot find start of image byteData! Returning empty image.'
end
fclose(fid);

% Removing info fields from header
for i = 1:size(infofields, 1)
    name = strtrim(infofields(i, :));
    sxm.header=rmfield(sxm.header, name);
end
