function out = set_options(xsd, xml)
%SET_OPTIONS Setting function options via a GUI
%   SET_OPTIONS(XSD, XML) takes the schema file XSD and a corresponding
%   XML-file XML and generates a GUI based upon these files (XSD determines
%   structure. XML determines default values).  The user can then edit the
%   GUI and save the result in a file using the "save To XML..."-link at
%   the top-left corner of the screen. Upon closing the result of the edit 
%   operations is returned in a Matlab structure.

import com.jaxfront.core.dom.*;
import com.jaxfront.core.util.*;
import com.jaxfront.swing.ui.editor.*;

inst = DOMBuilder.getInstance();
dom = inst.build('default-context', ...
    URLHelper.getUserURL(xsd), ...
    URLHelper.getUserURL(xml), ...
    [], []);
dom.getGlobalDefinition().setIsUsingButtonBar(false);
dom.getGlobalDefinition().setIsUsingStatusBar(false);

editorPanel = EditorPanel(...
    dom.getRootType(), []);
f=figure('Menubar', 'none', 'units', 'normalized', ...
    'outerposition', [0 0 1 1], 'Resize', 'off', ...
    'CloseRequestFcn', {@xml2struct});
set(f, 'visible', 'off');

uimenu('Label', 'Save to XML...', 'Callback', {@xml_save});
uicontrol('Style', 'pushbutton', ...
         'Units', 'normalized', ...
         'Position', [0 0 eps eps]);% Hack to save last change as well
GImport(f, editorPanel);
set(f, 'outerposition', [0 0 1 1]); %Not sure why this needs to be repeated
uiwait(f);

    function xml_save(~, ~)
    [filename, pathname] = uiputfile('*.xml', 'Save Workspace as');
    out_file= java.io.File(fullfile(pathname, filename)); 
    dom.saveAs(out_file);
    end

    function xml2struct(~, ~)
        uiresume(f);
        editorPanel.nextFocus(); % Hack to save last change as well
        delete(f);
        w3cdom = dom.serializeToW3CDocument();
        out = xml_read(w3cdom);
        out = rmfield(out, 'ATTRIBUTE');
        editorPanel.release();
        dom.release();
        %inst = [];
    end
end