function success = xml_validate(xml, xsd)
% XML_VALIDATE XML schema validation
%   XML_VALIDATE(XML, XSD) returns the result of validating the XML
%   file/dom tree against the schema file XSD.

% Import Java classes
import java.io.*;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.*;

% Check/process input arguments
if verLessThan('matlab', '7.14')
    error(nargchk(2, 2, nargin));
else
    narginchk(2, 2);
end
if ischar(xml) && exist(xml, 'file')
    xml = get_full_path(xml);
    source = javax.xml.transform.stream.StreamSource(xml);
elseif (isa(xml, 'org.apache.xerces.dom.DocumentImpl')||...
    isa(xml, 'org.apache.xerces.dom.DeferredDocumentImpl'))
    xml_string=xmlwrite_xerces(xml);
    js = java.lang.String(xml_string);
    %source= StreamSource(ByteArrayInputStream(js.getBytes('utf-8')));
    source = StreamSource(StringReader(js));
else
     me = MException('spm:xml_validate:xmlInvalid', ...
         'First argument should be an XML file or a DOM node.');
     throw(me);
end
if ~ischar(xsd) || ~exist(xsd, 'file')
    me = MException('spm:xml_validate:xmlInvalid', ...
        'Second argument should be an XML schema file.');
    throw(me);
end
xsd = get_full_path(xsd);

% Construct a validator for the schema
factory = SchemaFactory.newInstance('http://www.w3.org/2001/XMLSchema');
schemaLocation = File(xsd);
schema = factory.newSchema(schemaLocation);
validator = schema.newValidator();

% Validate the XML against the schema
try
	validator.validate(source);
catch ME
	 fprintf(ME.message);
     success = false;
     return;
end

success = true;
end

