function out = mirror(in, axis)
%MIRROR Mirroring of the pixels of a channel along an axis.
%   MIRROR(IN, AXIS) returns the result of mirroring channel IN of type 
%   'imageScan' along the axis AXIS ('x' or 'y').

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @(in)(is_channel(in) && ...
        strcmp(in.type,'imageScan')));
    parser.addRequired('axis', @(axis)(ischar(axis) && ...
        (strcmp(axis,'x') || strcmp(axis,'y'))));
    parser.parse(in, axis);
catch error
    me = MException('spm:mirror:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Flip
out = in;
switch axis
    case 'x'
        out.pixels = flipud(out.pixels);
    case 'y'
        out.pixels = fliplr(out.pixels);
end

end

