function out = select_range(in, varargin)
%SELECT_RANGE Pixel value range mask.
%   SELECT_RANGE(IN, VALUE1, VALUE2) sets all the pixels in IN > value1 and 
%   < value2 to one and all others to zero returns the resulting channel.
%   SELECT_RANGE(IN, VALUE) sets all pixels with value VALUE to one and all
%   others to zero.

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @is_channel);
    parser.addRequired('value1', @isfloat);
    parser.addOptional('value2','NaN', @isfloat);
    parser.parse(in, varargin{:});
catch error
    me = MException('spm:select_range:input_error', 'Invalid input: %s', ...
        error.message);
    throw(me);
end

% Copy input
out = in;

% Construct mask
if nargin == 3
    out.pixels = double(out.pixels > varargin{1} & ...
        out.pixels < varargin{2}); 
else
     out.pixels = double(out.pixels == varargin{1});
end

% Adapt channel name and units
if nargin == 3
    out.name = sprintf('%f < %s  < %f', varargin{1}, out.name, ...
        varargin{2});
else
    out.name = sprintf('%s == %f', out.name, varargin{1});
end
out.unit = '1';
out.display_unit = '1';
out.display_scale = 1;

end

