function [session_file, nof_lines] = preserve_session()
%PRESERVE_SESSION Save session command history PRESERVE_SESSION saves the
% commands of the current session up to the last command entered and
% returns the name of the session file. The underlying code is inspired on
% the Matlab Central  submission "Save Entire Command History" by Jonathan
% Snell (see http://goo.gl/0ddsu).

% Open history file
[fid, ~] = fopen(fullfile(prefdir,'history.m'), 'r');
cleanup1 = onCleanup(@()fclose(fid));
if fid == -1
    me = MException('spm:preserve_session:no_history_file', ...
        'Cannot open history file.');
    throw(me);
end
    
% Find last date in history file
k=0;
date_line = '';
date_line_pos = -1;
while ~feof(fid)
    k = k+1;
    line = fgetl(fid);
    if regexp(line,'%-- ') == 1
        date_line = line;
        date_line_pos = ftell(fid);
    end
end
if date_line_pos == -1
    warning('spm:preserve_session:no_date_line', ...
        'No date line found. Copying entire history.');
end
fseek(fid,date_line_pos,'bof');

% Open output file 
date_time = strrep(date_line,'%--','');
date_time  = strrep(date_time,'--%','');
if ~isempty(date_time)
    session_file = [datestr(date_time, 'yyyymmddTHHMMSS'), '.m'];
else
    session_file = [datestr(now, 'yyyymmddTHHMMSS'), '.m'];
end
[fid_out, ~] = fopen(fullfile(prefdir,session_file), 'w');
cleanup2 = onCleanup(@()fclose(fid_out));

nof_lines = 0;
while ~feof(fid)
    line = fgets(fid);
    fprintf(fid_out,'%s',line);
    nof_lines = nof_lines + 1;
end


end

